@@ -15,6 +15,7 @@
 from awips.dataaccess import IData
 import six
 
+
 class PyData(IData):
 
     def __init__(self, dataRecord):
@@ -24,11 +25,10 @@ class PyData(IData):
         self.__attributes = dataRecord.getAttributes()
 
     def getAttribute(self, key):
-        value = self.__attributes[key]
-        return value
+        return self.__attributes[key]
 
     def getAttributes(self):
-        return list(self.__attributes.keys())
+        return self.__attributes.keys()
 
     def getDataTime(self):
         return self.__time
@@ -36,7 +36,7 @@ class PyData(IData):
     def getLevel(self):
         if six.PY2:
             return self.__level
-        if type(self.__level) is not str:
+        if not isinstance(self.__level, str):
             return self.__level.decode('utf-8')
         return self.__level
 
