@@ -10,6 +10,7 @@
 #    09/07/17        6175          tgurney        Override messageReceived
 #
 
+import traceback
 import dynamicserialize
 from awips.dataaccess.PyNotification import PyNotification
 
@@ -27,7 +28,7 @@ class PyGeometryNotification(PyNotification):
             try:
                 data = self.getData(self.request, list(dataTimes))
                 self.callback(data)
-            except Exception:
+            except ValueError:
                 traceback.print_exc()
 
     def getData(self, request, dataTimes):
