@@ -14,7 +14,6 @@
 #
 #
 
-
 import numpy
 import warnings
 import six
@@ -29,7 +28,7 @@ The ability to unit convert grid data is not currently available in this version
 
 class PyGridData(IGridData, PyData.PyData):
 
-    def __init__(self, gridDataRecord, nx, ny, latLonGrid = None, latLonDelegate = None):
+    def __init__(self, gridDataRecord, nx, ny, latLonGrid=None, latLonDelegate=None):
         PyData.PyData.__init__(self, gridDataRecord)
         nx = nx
         ny = ny
@@ -39,14 +38,13 @@ class PyGridData(IGridData, PyData.PyData):
         self.__latLonGrid = latLonGrid
         self.__latLonDelegate = latLonDelegate
 
-
     def getParameter(self):
         return self.__parameter
 
     def getUnit(self):
         if six.PY2:
             return self.__unit
-        if self.__unit is not None and type(self.__unit) is not str:
+        if self.__unit is not None and not isinstance(self.__unit, str):
             return self.__unit.decode('utf-8')
         return self.__unit
 
