@@ -2,7 +2,6 @@
 # Routes requests to the Data Access Framework through Python Thrift.
 #
 #
-#
 #    SOFTWARE HISTORY
 #
 #    Date            Ticket#       Engineer       Description
@@ -23,7 +22,6 @@
 #    10/26/16        5919          njensen        Speed up geometry creation in getGeometryData()
 #
 
-
 import numpy
 import six
 import shapely.wkb
@@ -226,7 +224,8 @@ class ThriftClientRouter(object):
             return [x.decode('utf-8') for x in response]
         return response
 
-    def newDataRequest(self, datatype, parameters=[], levels=[], locationNames=[], envelope=None, **kwargs):
+    def newDataRequest(self, datatype, parameters=[], levels=[], locationNames=[],
+                       envelope=None, **kwargs):
         req = DefaultDataRequest()
         if datatype:
             req.setDatatype(datatype)
