@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # __init__.py for awips.dataaccess package
 #
@@ -22,12 +18,19 @@
 #
 
 __all__ = [
-
-           ]
+    'IData',
+    'IDataRequest',
+    'IGeometryData',
+    'IGridData',
+    'IGeometryData',
+    'INotificationFilter',
+    'INotificationSubscriber'
+]
 
 import abc
 from six import with_metaclass
 
+
 class IDataRequest(with_metaclass(abc.ABCMeta, object)):
     """
     An IDataRequest to be submitted to the DataAccessLayer to retrieve data.
@@ -148,7 +151,6 @@ class IDataRequest(with_metaclass(abc.ABCMeta, object)):
         return
 
 
-
 class IData(with_metaclass(abc.ABCMeta, object)):
     """
     An IData representing data returned from the DataAccessLayer.
@@ -209,7 +211,6 @@ class IData(with_metaclass(abc.ABCMeta, object)):
         return
 
 
-
 class IGridData(IData):
     """
     An IData representing grid data that is returned by the DataAccessLayer.
@@ -257,7 +258,6 @@ class IGridData(IData):
         return
 
 
-
 class IGeometryData(IData):
     """
     An IData representing geometry data that is returned by the DataAccessLayer.
@@ -359,6 +359,7 @@ class INotificationSubscriber(with_metaclass(abc.ABCMeta, object)):
         """Closes the notification subscriber"""
         pass
 
+
 class INotificationFilter(with_metaclass(abc.ABCMeta, object)):
     """
     Represents data required to filter a set of URIs and
