@@ -1,5 +1,16 @@
-from awips import ThriftClient
+#
+# Provides a Python-based interface for executing GFE requests.
+#
+#
+#     SOFTWARE HISTORY
+#
+#    Date            Ticket#       Engineer       Description
+#    ------------    ----------    -----------    --------------------------
+#    07/26/12                      dgilling       Initial Creation.
+#
+#
 
+from awips import ThriftClient
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.db.objects import DatabaseID
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.db.objects import ParmID
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.request import CommitGridsRequest
@@ -12,21 +23,6 @@ from dynamicserialize.dstypes.com.raytheon.uf.common.site.requests import GetAct
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.server.message import ServerResponse
 
 
-#
-# Provides a Python-based interface for executing GFE requests.
-#
-#
-#
-#     SOFTWARE HISTORY
-#
-#    Date            Ticket#       Engineer       Description
-#    ------------    ----------    -----------    --------------------------
-#    07/26/12                      dgilling       Initial Creation.
-#
-#
-#
-
-
 class IFPClient(object):
     def __init__(self, host, port, user, site=None, progName=None):
         self.__thrift = ThriftClient.ThriftClient(host, port)
@@ -39,11 +35,12 @@ class IFPClient(object):
         self.__siteId = site
 
     def commitGrid(self, request):
-        if type(request) is CommitGridRequest:
+        if isinstance(request, CommitGridRequest):
             return self.__commitGrid([request])
         elif self.__isHomogenousIterable(request, CommitGridRequest):
             return self.__commitGrid([cgr for cgr in request])
-        raise TypeError("Invalid type: " + str(type(request)) + " specified to commitGrid(). Only accepts CommitGridRequest or lists of CommitGridRequest.")
+        raise TypeError("Invalid type: " + str(type(request)) +
+                        " for commitGrid(). Only accepts CommitGridRequest or lists of CommitGridRequest.")
 
     def __commitGrid(self, requests):
         ssr = ServerResponse()
@@ -53,13 +50,14 @@ class IFPClient(object):
         ssr.setMessages(sr.getMessages())
         return ssr
 
-    def getParmList(self, id):
-        argType = type(id)
+    def getParmList(self, pid):
+        argType = type(pid)
         if argType is DatabaseID:
-            return self.__getParmList([id])
-        elif self.__isHomogenousIterable(id, DatabaseID):
-            return self.__getParmList([dbid for dbid in id])
-        raise TypeError("Invalid type: " + str(argType) + " specified to getParmList(). Only accepts DatabaseID or lists of DatabaseID.")
+            return self.__getParmList([pid])
+        elif self.__isHomogenousIterable(pid, DatabaseID):
+            return self.__getParmList([dbid for dbid in pid])
+        raise TypeError("Invalid type: " + str(argType) +
+                        " for getParmList(). Only accepts DatabaseID or lists of DatabaseID.")
 
     def __getParmList(self, ids):
         ssr = ServerResponse()
@@ -67,8 +65,8 @@ class IFPClient(object):
         request.setDbIds(ids)
         sr = self.__makeRequest(request)
         ssr.setMessages(sr.getMessages())
-        list = sr.getPayload() if sr.getPayload() is not None else []
-        ssr.setPayload(list)
+        parmlist = sr.getPayload() if sr.getPayload() is not None else []
+        ssr.setPayload(parmlist)
         return ssr
 
     def __isHomogenousIterable(self, iterable, classType):
@@ -82,19 +80,20 @@ class IFPClient(object):
         return True
 
     def getGridInventory(self, parmID):
-        if type(parmID) is ParmID:
+        if isinstance(parmID, ParmID):
             sr = self.__getGridInventory([parmID])
-            list = []
+            inventoryList = []
             try:
-                list = sr.getPayload()[parmID]
+                inventoryList = sr.getPayload()[parmID]
             except KeyError:
                 # no-op, we've already default the TimeRange list to empty
                 pass
-            sr.setPayload(list)
+            sr.setPayload(inventoryList)
             return sr
         elif self.__isHomogenousIterable(parmID, ParmID):
-            return self.__getGridInventory([id for id in parmID])
-        raise TypeError("Invalid type: " + str(type(parmID)) + " specified to getGridInventory(). Only accepts ParmID or lists of ParmID.")
+            return self.__getGridInventory([pid for pid in parmID])
+        raise TypeError("Invalid type: " + str(type(parmID)) +
+                        " specified to getGridInventory(). Accepts ParmID or lists of ParmID.")
 
     def __getGridInventory(self, parmIDs):
         ssr = ServerResponse()
