@@ -1,11 +1,3 @@
-from __future__ import print_function
-from awips.dataaccess import DataAccessLayer as DAL
-from awips.ThriftClient import ThriftRequestException
-from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
-
-from awips.test.dafTests import baseDafTestCase
-import unittest
-
 #
 # Test DAF support for binlightning data
 #
@@ -28,6 +20,11 @@ import unittest
 #    11/08/16        5985          tgurney        Do not check data times
 #
 #
+from __future__ import print_function
+from awips.dataaccess import DataAccessLayer as DAL
+from awips.ThriftClient import ThriftRequestException
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
+from awips.test.dafTests import baseDafTestCase
 
 
 class BinLightningTestCase(baseDafTestCase.DafTestCase):
@@ -89,11 +86,6 @@ class BinLightningTestCase(baseDafTestCase.DafTestCase):
         for record in geomData:
             self.assertEqual(record.getAttribute('source'), self.source)
 
-    def testGetDataWithEqualsUnicode(self):
-        geomData = self._runConstraintTest('source', '=', self.source)
-        for record in geomData:
-            self.assertEqual(record.getAttribute('source'), self.source)
-
     def testGetDataWithEqualsInt(self):
         geomData = self._runConstraintTest('source', '=', 1000)
         for record in geomData:
