@@ -4,7 +4,6 @@ from awips.dataaccess import DataAccessLayer as DAL
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
 from awips.test.dafTests import baseDafTestCase
 from awips.test.dafTests import params
-import unittest
 
 #
 # Test DAF support for bufrua data
@@ -106,11 +105,6 @@ class BufrUaTestCase(baseDafTestCase.DafTestCase):
         for record in geometryData:
             self.assertEqual(record.getString('rptType'), '2022')
 
-    def testGetDataWithEqualsUnicode(self):
-        geometryData = self._runConstraintTest('reportType', '=', u'2022')
-        for record in geometryData:
-            self.assertEqual(record.getString('rptType'), '2022')
-
     def testGetDataWithEqualsInt(self):
         geometryData = self._runConstraintTest('reportType', '=', 2022)
         for record in geometryData:
