@@ -1,9 +1,3 @@
-from awips.dataaccess import DataAccessLayer as DAL
-from awips.dataaccess import CombinedTimeQuery as CTQ
-
-import unittest
-import os
-
 #
 # Test the CombinedTimedQuery module
 #
@@ -17,9 +11,17 @@ import os
 #
 #
 
+from awips.dataaccess import DataAccessLayer as DAL
+from awips.dataaccess import CombinedTimeQuery as CTQ
+
+import unittest
+import os
+
 
 class CombinedTimeQueryTestCase(unittest.TestCase):
 
+    modelName = "RAP13"
+
     @classmethod
     def setUp(cls):
         host = os.environ.get('DAF_TEST_HOST')
@@ -29,10 +31,10 @@ class CombinedTimeQueryTestCase(unittest.TestCase):
 
     def testSuccessfulQuery(self):
         req = DAL.newDataRequest('grid')
-        req.setLocationNames('RUC130')
-        req.setParameters('T','GH')
-        req.setLevels('300MB', '500MB','700MB')
-        times = CTQ.getAvailableTimes(req);
+        req.setLocationNames(self.modelName)
+        req.setParameters('T', 'GH')
+        req.setLevels('300MB', '500MB', '700MB')
+        times = CTQ.getAvailableTimes(req)
         self.assertNotEqual(len(times), 0)
 
     def testNonIntersectingQuery(self):
@@ -40,8 +42,8 @@ class CombinedTimeQueryTestCase(unittest.TestCase):
         Test that when a parameter is only available on one of the levels that no times are returned.
         """
         req = DAL.newDataRequest('grid')
-        req.setLocationNames('RUC130')
-        req.setParameters('T','GH', 'LgSP1hr')
-        req.setLevels('300MB', '500MB','700MB','0.0SFC')
-        times = CTQ.getAvailableTimes(req);
+        req.setLocationNames(self.modelName)
+        req.setParameters('T', 'GH', 'LgSP1hr')
+        req.setLevels('300MB', '500MB', '700MB', '0.0SFC')
+        times = CTQ.getAvailableTimes(req)
         self.assertEqual(len(times), 0)
