@@ -1,13 +1,3 @@
-from __future__ import print_function
-from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
-from shapely.geometry import box, Point
-from awips.dataaccess import DataAccessLayer as DAL
-from awips.ThriftClient import ThriftRequestException
-
-from awips.test.dafTests import baseDafTestCase
-from awips.test.dafTests import params
-import unittest
-
 #
 # Test DAF support for grid data
 #
@@ -30,6 +20,16 @@ import unittest
 #                                                 data is available
 #
 
+from __future__ import print_function
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
+from awips.dataaccess import DataAccessLayer as DAL
+from awips.ThriftClient import ThriftRequestException
+from shapely.geometry import box, Point
+
+from awips.test.dafTests import baseDafTestCase
+from awips.test.dafTests import params
+import unittest
+
 
 class GridTestCase(baseDafTestCase.DafTestCase):
     """Test DAF support for grid data"""
@@ -86,7 +86,6 @@ class GridTestCase(baseDafTestCase.DafTestCase):
     def testGetNonexistentIdentifierValuesThrowsException(self):
         self.runNonexistentIdValuesTest()
 
-
     def testGetDataWithEnvelope(self):
         req = DAL.newDataRequest(self.datatype)
         req.addIdentifier('info.datasetId', self.model)
@@ -103,12 +102,11 @@ class GridTestCase(baseDafTestCase.DafTestCase):
         # Ensure all points are within one degree of the original box
         # to allow slight margin of error for reprojection distortion.
         testEnv = box(params.ENVELOPE.bounds[0] - 1, params.ENVELOPE.bounds[1] - 1,
-                      params.ENVELOPE.bounds[2] + 1, params.ENVELOPE.bounds[3] + 1 )
+                      params.ENVELOPE.bounds[2] + 1, params.ENVELOPE.bounds[3] + 1)
 
         for i in range(len(lons)):
             self.assertTrue(testEnv.contains(Point(lons[i], lats[i])))
 
-
     def _runConstraintTest(self, key, operator, value):
         req = DAL.newDataRequest(self.datatype)
         constraint = RequestConstraint.new(operator, value)
@@ -124,11 +122,6 @@ class GridTestCase(baseDafTestCase.DafTestCase):
         for record in gridData:
             self.assertEqual(record.getAttribute('info.level.levelonevalue'), 2000.0)
 
-    def testGetDataWithEqualsUnicode(self):
-        gridData = self._runConstraintTest('info.level.levelonevalue', '=', u'2000.0')
-        for record in gridData:
-            self.assertEqual(record.getAttribute('info.level.levelonevalue'), 2000.0)
-
     def testGetDataWithEqualsInt(self):
         gridData = self._runConstraintTest('info.level.levelonevalue', '=', 2000)
         for record in gridData:
