@@ -1,11 +1,3 @@
-from __future__ import print_function
-from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
-from awips.dataaccess import DataAccessLayer as DAL
-from awips.ThriftClient import ThriftRequestException
-
-from awips.test.dafTests import baseDafTestCase
-import unittest
-
 #
 # Test DAF support for maps data
 #
@@ -24,6 +16,13 @@ import unittest
 #
 #
 
+from __future__ import print_function
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
+from awips.dataaccess import DataAccessLayer as DAL
+from awips.ThriftClient import ThriftRequestException
+
+from awips.test.dafTests import baseDafTestCase
+
 
 class MapsTestCase(baseDafTestCase.DafTestCase):
     """Test DAF support for maps data"""
@@ -83,7 +82,7 @@ class MapsTestCase(baseDafTestCase.DafTestCase):
         req = DAL.newDataRequest(self.datatype)
         req.addIdentifier('geomField', 'the_geom')
         with self.assertRaises(ThriftRequestException):
-            idValues = DAL.getIdentifierValues(req, 'state')
+            DAL.getIdentifierValues(req, 'state')
 
     def testGetInvalidIdentifierValuesThrowsException(self):
         self.runInvalidIdValuesTest()
@@ -106,11 +105,6 @@ class MapsTestCase(baseDafTestCase.DafTestCase):
         for record in geometryData:
             self.assertEqual(record.getString('state'), 'NE')
 
-    def testGetDataWithEqualsUnicode(self):
-        geometryData = self._runConstraintTest('state', '=', u'NE')
-        for record in geometryData:
-            self.assertEqual(record.getString('state'), 'NE')
-
     def testGetDataWithEqualsInt(self):
         geometryData = self._runConstraintTest('reservoir', '=', 1)
         for record in geometryData:
