@@ -1,11 +1,3 @@
-from __future__ import print_function
-from awips.dataaccess import DataAccessLayer as DAL
-from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
-
-from awips.test.dafTests import baseDafTestCase
-from awips.test.dafTests import params
-import unittest
-
 #
 # Test DAF support for modelsounding data
 #
@@ -27,30 +19,39 @@ import unittest
 #
 #
 
+from __future__ import print_function
+from awips.dataaccess import DataAccessLayer as DAL
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
+
+from awips.test.dafTests import baseDafTestCase
+from awips.test.dafTests import params
+
 
 class ModelSoundingTestCase(baseDafTestCase.DafTestCase):
     """Test DAF support for modelsounding data"""
 
     datatype = "modelsounding"
 
+    reporttype = "ETA"
+
     def testGetAvailableParameters(self):
         req = DAL.newDataRequest(self.datatype)
         self.runParametersTest(req)
 
     def testGetAvailableLocations(self):
         req = DAL.newDataRequest(self.datatype)
-        req.addIdentifier("reportType", "ETA")
+        req.addIdentifier("reportType", self.reporttype)
         self.runLocationsTest(req)
 
     def testGetAvailableTimes(self):
         req = DAL.newDataRequest(self.datatype)
-        req.addIdentifier("reportType", "ETA")
+        req.addIdentifier("reportType", self.reporttype)
         req.setLocationNames(params.OBS_STATION)
         self.runTimesTest(req)
 
     def testGetGeometryData(self):
         req = DAL.newDataRequest(self.datatype)
-        req.addIdentifier("reportType", "ETA")
+        req.addIdentifier("reportType", self.reporttype)
         req.setLocationNames(params.OBS_STATION)
         req.setParameters("temperature", "pressure", "specHum", "sfcPress", "temp2", "q2")
         print("Testing getGeometryData()")
@@ -80,7 +81,7 @@ class ModelSoundingTestCase(baseDafTestCase.DafTestCase):
 
     def testGetGeometryDataWithEnvelope(self):
         req = DAL.newDataRequest(self.datatype)
-        req.addIdentifier("reportType", "ETA")
+        req.addIdentifier("reportType", self.reporttype)
         req.setEnvelope(params.ENVELOPE)
         req.setParameters("temperature", "pressure", "specHum", "sfcPress", "temp2", "q2")
         print("Testing getGeometryData()")
@@ -120,15 +121,10 @@ class ModelSoundingTestCase(baseDafTestCase.DafTestCase):
         for record in geometryData:
             self.assertIn('/ETA/', record.getString('dataURI'))
 
-    def testGetDataWithEqualsUnicode(self):
-        geometryData = self._runConstraintTest('reportType', '=', u'ETA')
-        for record in geometryData:
-            self.assertIn('/ETA/', record.getString('dataURI'))
-
     # No numeric tests since no numeric identifiers are available.
 
     def testGetDataWithEqualsNone(self):
-        geometryData = self._runConstraintTest('reportType', '=', None)
+        self._runConstraintTest('reportType', '=', None)
 
     def testGetDataWithNotEquals(self):
         geometryData = self._runConstraintTest('reportType', '!=', 'ETA')
@@ -136,19 +132,19 @@ class ModelSoundingTestCase(baseDafTestCase.DafTestCase):
             self.assertNotIn('/ETA/', record.getString('dataURI'))
 
     def testGetDataWithNotEqualsNone(self):
-        geometryData = self._runConstraintTest('reportType', '!=', None)
+        self._runConstraintTest('reportType', '!=', None)
 
     def testGetDataWithGreaterThan(self):
-        geometryData = self._runConstraintTest('reportType', '>', 'ETA')
+        self._runConstraintTest('reportType', '>', 'ETA')
 
     def testGetDataWithLessThan(self):
-        geometryData = self._runConstraintTest('reportType', '<', 'ETA')
+        self._runConstraintTest('reportType', '<', 'ETA')
 
     def testGetDataWithGreaterThanEquals(self):
-        geometryData = self._runConstraintTest('reportType', '>=', 'ETA')
+        self._runConstraintTest('reportType', '>=', 'ETA')
 
     def testGetDataWithLessThanEquals(self):
-        geometryData = self._runConstraintTest('reportType', '<=', 'ETA')
+        self._runConstraintTest('reportType', '<=', 'ETA')
 
     def testGetDataWithInTuple(self):
         collection = ('ETA', 'GFS')
