@@ -1,10 +1,3 @@
-from __future__ import print_function
-from awips.dataaccess import DataAccessLayer as DAL
-from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
-
-from awips.test.dafTests import baseDafTestCase
-from awips.test.dafTests import params
-
 #
 # Test DAF support for obs data
 #
@@ -23,6 +16,13 @@ from awips.test.dafTests import params
 #
 #
 
+from __future__ import print_function
+from awips.dataaccess import DataAccessLayer as DAL
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
+
+from awips.test.dafTests import baseDafTestCase
+from awips.test.dafTests import params
+
 
 class ObsTestCase(baseDafTestCase.DafTestCase):
     """Test DAF support for obs data"""
@@ -46,7 +46,7 @@ class ObsTestCase(baseDafTestCase.DafTestCase):
         req = DAL.newDataRequest(self.datatype)
         req.setLocationNames(params.OBS_STATION)
         req.setParameters("temperature", "seaLevelPress", "dewpoint")
-        data = self.runGeometryDataTest(req)
+        self.runGeometryDataTest(req)
 
     def testGetGeometryDataWithEnvelope(self):
         req = DAL.newDataRequest(self.datatype)
@@ -80,11 +80,6 @@ class ObsTestCase(baseDafTestCase.DafTestCase):
         for record in geometryData:
             self.assertEqual(record.getString('reportType'), 'METAR')
 
-    def testGetDataWithEqualsUnicode(self):
-        geometryData = self._runConstraintTest('reportType', '=', u'METAR')
-        for record in geometryData:
-            self.assertEqual(record.getString('reportType'), 'METAR')
-
     # No numeric tests since no numeric identifiers are available.
 
     def testGetDataWithEqualsNone(self):
