@@ -1,7 +1,3 @@
-from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
-
-import unittest
-
 #
 # Unit tests for Python implementation of RequestConstraint
 #
@@ -13,6 +9,10 @@ import unittest
 #
 #
 
+from dynamicserialize.dstypes.com.raytheon.uf.common.dataquery.requests import RequestConstraint
+
+import unittest
+
 
 class RequestConstraintTestCase(unittest.TestCase):
 
@@ -134,73 +134,6 @@ class RequestConstraintTestCase(unittest.TestCase):
         self.assertFalse(new('not in', 'a').evaluate('a'))
         self.assertFalse(new('not in', [1.0001, 2, 3]).evaluate(2.0 - 0.9999))
 
-    def testEvaluateLike(self):
-        # cannot make "like" with RequestConstraint.new()
-        new = self._newRequestConstraint
-        self.assertTrue(new('LIKE', 'a').evaluate('a'))
-        self.assertTrue(new('LIKE', 'a%').evaluate('a'))
-        self.assertTrue(new('LIKE', 'a%').evaluate('abcd'))
-        self.assertTrue(new('LIKE', '%a').evaluate('a'))
-        self.assertTrue(new('LIKE', '%a').evaluate('bcda'))
-        self.assertTrue(new('LIKE', '%').evaluate(''))
-        self.assertTrue(new('LIKE', '%').evaluate('anything'))
-        self.assertTrue(new('LIKE', 'a%d').evaluate('ad'))
-        self.assertTrue(new('LIKE', 'a%d').evaluate('abcd'))
-        self.assertTrue(new('LIKE', 'aa.()!{[]^%$').evaluate('aa.()!{[]^zzz$'))
-        self.assertTrue(new('LIKE', 'a__d%').evaluate('abcdefg'))
-        self.assertFalse(new('LIKE', 'a%').evaluate('b'))
-        self.assertFalse(new('LIKE', 'a%').evaluate('ba'))
-        self.assertFalse(new('LIKE', '%a').evaluate('b'))
-        self.assertFalse(new('LIKE', '%a').evaluate('ab'))
-        self.assertFalse(new('LIKE', 'a%').evaluate('A'))
-        self.assertFalse(new('LIKE', 'A%').evaluate('a'))
-        self.assertFalse(new('LIKE', 'a%d').evaluate('da'))
-        self.assertFalse(new('LIKE', 'a__d%').evaluate('abccdefg'))
-        self.assertFalse(new('LIKE', '....').evaluate('aaaa'))
-        self.assertFalse(new('LIKE', '.*').evaluate('anything'))
-
-    def testEvaluateILike(self):
-        # cannot make "ilike" with RequestConstraint.new()
-        new = self._newRequestConstraint
-        self.assertTrue(new('ILIKE', 'a').evaluate('a'))
-        self.assertTrue(new('ILIKE', 'a%').evaluate('a'))
-        self.assertTrue(new('ILIKE', 'a%').evaluate('abcd'))
-        self.assertTrue(new('ILIKE', '%a').evaluate('a'))
-        self.assertTrue(new('ILIKE', '%a').evaluate('bcda'))
-        self.assertTrue(new('ILIKE', '%').evaluate(''))
-        self.assertTrue(new('ILIKE', '%').evaluate('anything'))
-        self.assertTrue(new('ILIKE', 'a%d').evaluate('ad'))
-        self.assertTrue(new('ILIKE', 'a%d').evaluate('abcd'))
-        self.assertTrue(new('ILIKE', 'a').evaluate('A'))
-        self.assertTrue(new('ILIKE', 'a%').evaluate('A'))
-        self.assertTrue(new('ILIKE', 'a%').evaluate('ABCD'))
-        self.assertTrue(new('ILIKE', '%a').evaluate('A'))
-        self.assertTrue(new('ILIKE', '%a').evaluate('BCDA'))
-        self.assertTrue(new('ILIKE', '%').evaluate(''))
-        self.assertTrue(new('ILIKE', '%').evaluate('anything'))
-        self.assertTrue(new('ILIKE', 'a%d').evaluate('AD'))
-        self.assertTrue(new('ILIKE', 'a%d').evaluate('ABCD'))
-        self.assertTrue(new('ILIKE', 'A').evaluate('a'))
-        self.assertTrue(new('ILIKE', 'A%').evaluate('a'))
-        self.assertTrue(new('ILIKE', 'A%').evaluate('abcd'))
-        self.assertTrue(new('ILIKE', '%A').evaluate('a'))
-        self.assertTrue(new('ILIKE', '%A').evaluate('bcda'))
-        self.assertTrue(new('ILIKE', '%').evaluate(''))
-        self.assertTrue(new('ILIKE', '%').evaluate('anything'))
-        self.assertTrue(new('ILIKE', 'A%D').evaluate('ad'))
-        self.assertTrue(new('ILIKE', 'A%D').evaluate('abcd'))
-        self.assertTrue(new('ILIKE', 'aa.()!{[]^%$').evaluate('AA.()!{[]^zzz$'))
-        self.assertTrue(new('ILIKE', 'a__d%').evaluate('abcdefg'))
-        self.assertTrue(new('ILIKE', 'a__d%').evaluate('ABCDEFG'))
-        self.assertFalse(new('ILIKE', 'a%').evaluate('b'))
-        self.assertFalse(new('ILIKE', 'a%').evaluate('ba'))
-        self.assertFalse(new('ILIKE', '%a').evaluate('b'))
-        self.assertFalse(new('ILIKE', '%a').evaluate('ab'))
-        self.assertFalse(new('ILIKE', 'a%d').evaluate('da'))
-        self.assertFalse(new('ILIKE', 'a__d%').evaluate('abccdefg'))
-        self.assertFalse(new('ILIKE', '....').evaluate('aaaa'))
-        self.assertFalse(new('ILIKE', '.*').evaluate('anything'))
-
     def testEvaluateBetween(self):
         # cannot make "between" with RequestConstraint.new()
         new = self._newRequestConstraint
