@@ -1,10 +1,3 @@
-##
-##
-
-
-#
-# TODO
-#
 #
 #     SOFTWARE HISTORY
 #
@@ -13,13 +6,13 @@
 #    08/20/10                      njensen       Initial Creation.
 #
 #
-#
 
 __all__ = ['SerializationException']
 
 from . import dstypes, adapters
 from . import DynamicSerializationManager
 
+
 class SerializationException(Exception):
 
     def __init__(self, message=None):
@@ -31,10 +24,12 @@ class SerializationException(Exception):
         else:
             return ""
 
+
 def serialize(obj):
     dsm = DynamicSerializationManager.DynamicSerializationManager()
     return dsm.serializeObject(obj)
 
-def deserialize(bytes):
+
+def deserialize(objbytes):
     dsm = DynamicSerializationManager.DynamicSerializationManager()
-    return dsm.deserializeBytes(bytes)
+    return dsm.deserializeBytes(objbytes)
