@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Adapter for java.nio.ByteBuffer
 #
@@ -12,18 +8,14 @@
 #    ------------    ----------    -----------    --------------------------
 #    08/03/11                      dgilling       Initial Creation.
 #
-#
-#
 
 ClassAdapter = ['java.nio.ByteBuffer', 'java.nio.HeapByteBuffer']
 
 
-def serialize(context, set):
+def serialize(context, bufferset):
     raise NotImplementedError("Serialization of ByteBuffers is not supported.")
 
+
 def deserialize(context):
     byteBuf = context.readBinary()
     return byteBuf
-
-
-
