@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Adapter for java.util.EnumSet
 #
@@ -13,21 +9,17 @@
 #    07/28/11                      dgilling       Initial Creation.
 #    12/02/13        2537          bsteffen       Serialize empty enum sets.
 #
-#
-#
-
-
 
 from dynamicserialize.dstypes.java.util import EnumSet
 
 ClassAdapter = ['java.util.EnumSet', 'java.util.RegularEnumSet']
 
 
-def serialize(context, set):
-    setSize = len(set)
+def serialize(context, bufferset):
+    setSize = len(bufferset)
     context.writeI32(setSize)
-    context.writeString(set.getEnumClass())
-    for val in set:
+    context.writeString(bufferset.getEnumClass())
+    for val in bufferset:
         context.writeString(val)
 
 
@@ -35,6 +27,6 @@ def deserialize(context):
     setSize = context.readI32()
     enumClassName = context.readString()
     valList = []
-    for i in range(setSize):
+    for __ in range(setSize):
         valList.append(context.readString())
     return EnumSet(enumClassName, valList)
