@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Adapter for java.nio.FloatBuffer
 #
@@ -12,18 +8,14 @@
 #    ------------    ----------    -----------    --------------------------
 #    08/01/11                      dgilling       Initial Creation.
 #
-#
-#
 
 ClassAdapter = ['java.nio.FloatBuffer', 'java.nio.HeapFloatBuffer']
 
 
-def serialize(context, set):
+def serialize(context, bufferset):
     raise NotImplementedError("Serialization of FloatBuffers is not supported.")
 
+
 def deserialize(context):
     floatBuf = context.readFloatArray()
     return floatBuf
-
-
-
