@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Adapter for com.raytheon.uf.common.localization.LocalizationContext$LocalizationLevel
 #
@@ -12,10 +8,6 @@
 #    ------------    ----------    -----------    --------------------------
 #    01/11/11                      dgilling       Initial Creation.
 #
-#
-#
-
-
 
 from dynamicserialize.dstypes.com.raytheon.uf.common.localization import LocalizationLevel
 
@@ -24,10 +16,12 @@ ClassAdapter = [
                  'com.raytheon.uf.common.localization.LocalizationLevel'
                 ]
 
+
 def serialize(context, level):
     context.writeString(level.getText())
     context.writeI32(level.getOrder())
-    context.writeBool(level.isSystemLevel());
+    context.writeBool(level.isSystemLevel())
+
 
 def deserialize(context):
     text = context.readString()
@@ -35,5 +29,3 @@ def deserialize(context):
     systemLevel = context.readBool()
     level = LocalizationLevel(text, order, systemLevel=systemLevel)
     return level
-
-
