@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Adapter for com.raytheon.uf.common.localization.LocalizationContext$LocalizationType
 #
@@ -12,10 +8,6 @@
 #    ------------    ----------    -----------    --------------------------
 #    01/11/11                      dgilling       Initial Creation.
 #
-#
-#
-
-
 
 from dynamicserialize.dstypes.com.raytheon.uf.common.localization import LocalizationType
 
@@ -24,10 +16,11 @@ ClassAdapter = [
                 'com.raytheon.uf.common.localization.LocalizationType'
                 ]
 
-def serialize(context, type):
-    context.writeString(type.getText())
+
+def serialize(context, ltype):
+    context.writeString(ltype.getText())
+
 
 def deserialize(context):
     typeString = context.readString()
     return LocalizationType(typeString)
-
