@@ -1,7 +1,3 @@
-##
-##
-
-
 #
 # Adapter for com.raytheon.uf.common.dataplugin.gfe.db.objects.ParmID
 #
@@ -12,17 +8,17 @@
 #    ------------    ----------    -----------    --------------------------
 #    03/20/13           #1774      randerso       Initial Creation.
 #
-#
-#
 
 from dynamicserialize.dstypes.com.raytheon.uf.common.dataplugin.gfe.db.objects import TimeConstraints
 
 ClassAdapter = 'com.raytheon.uf.common.dataplugin.gfe.db.objects.TimeConstraints'
 
+
 def serialize(context, timeConstraints):
-    context.writeI32(timeConstraints.getDuration());
-    context.writeI32(timeConstraints.getRepeatInterval());
-    context.writeI32(timeConstraints.getStartTime());
+    context.writeI32(timeConstraints.getDuration())
+    context.writeI32(timeConstraints.getRepeatInterval())
+    context.writeI32(timeConstraints.getStartTime())
+
 
 def deserialize(context):
     result = TimeConstraints(context.readI32(), context.readI32(), context.readI32())
