@@ -1,6 +1,3 @@
-##
-##
-
 #
 # Package definition for com.raytheon.uf.common.datastorage.records
 #
@@ -12,11 +9,9 @@
 #    08/31/10                      njensen        Initial Creation.
 #    Apr 24, 2015    4425          nabowle        Add DoubleDataRecord
 #
-#
-#
-
 
 __all__ = [
+            'AbstractDataRecord',
             'ByteDataRecord',
             'DoubleDataRecord',
             'FloatDataRecord',
@@ -26,6 +21,7 @@ __all__ = [
             'StringDataRecord'
           ]
 
+from .AbstractDataRecord import AbstractDataRecord
 from .ByteDataRecord import ByteDataRecord
 from .DoubleDataRecord import DoubleDataRecord
 from .FloatDataRecord import FloatDataRecord
@@ -33,4 +29,3 @@ from .IntegerDataRecord import IntegerDataRecord
 from .LongDataRecord import LongDataRecord
 from .ShortDataRecord import ShortDataRecord
 from .StringDataRecord import StringDataRecord
-
