@@ -1,5 +1,3 @@
-##
-##
 #
 #     SOFTWARE HISTORY
 #
@@ -7,7 +5,7 @@
 #    ------------    ----------    -----------    --------------------------
 #    09/10/14         #3623        randerso       Manually created, do not regenerate
 #
-##
+
 
 class SiteActivationNotification(object):
 
@@ -23,8 +21,8 @@ class SiteActivationNotification(object):
     def getType(self):
         return self.type
 
-    def setType(self, type):
-        self.type = type
+    def setType(self, notificationType):
+        self.type = notificationType
 
     def getStatus(self):
         return self.status
@@ -33,10 +31,10 @@ class SiteActivationNotification(object):
         self.status = status
 
     def getPrimarySite(self):
-        return self.primarysite
+        return self.primarySite
 
     def setPrimarySite(self, primarysite):
-        self.primarysite = primarysite
+        self.primarySite = primarysite
 
     def getModifiedSite(self):
         return self.modifiedSite
