@@ -1,6 +1,3 @@
-##
-##
-# ----------------------------------------------------------------------------
 #
 #     SOFTWARE HISTORY
 #
@@ -8,13 +5,11 @@
 #    ------------    ----------    -----------    --------------------------
 #    06/23/2016      #5696         rjpeter        Initial creation.
 #
-##
 
-from time import gmtime, strftime
 from dynamicserialize.dstypes.java.sql import Timestamp
 
+
 class CommutativeTimestamp(Timestamp):
 
     def __init__(self, timeInMillis=None):
         super(CommutativeTimestamp, self).__init__(timeInMillis)
-
